@@ -1425,6 +1425,7 @@ s_chtml20_start_form_tag(void *pdoc, Node *node)
   Doc *doc;
   request_rec *r;
   Attr *attr;
+  char *new_hidden_tag = NULL;
 
   chtml20 = GET_CHTML20(pdoc);
   doc     = chtml20->doc;
@@ -1453,6 +1454,12 @@ s_chtml20_start_form_tag(void *pdoc, Node *node)
         /*--------------------------------------------------------------------*/
         value = chxj_encoding_parameter(r, value);
         value = chxj_add_cookie_parameter(r, value, chtml20->cookie);
+        char *q;
+        q = strchr(value, '?');
+        if (q) {
+          new_hidden_tag = chxj_form_action_to_hidden_tag(doc->pool, value, 0);
+          *q = 0;
+        }
 
         W_L(" action=\"");
         W_V(value);
@@ -1487,6 +1494,9 @@ s_chtml20_start_form_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
+  if (new_hidden_tag) {
+    W_V(new_hidden_tag);
+  }
   return chtml20->out;
 }
 
